# Author: Theophanis Tsandilas
library(plotrix)

#read the data from a csv file
data <- read.csv(file="IQ-tests.csv", header=TRUE, sep=",")

# omit the group column
data <- aggregate(score~participant+week, data, FUN = mean)

# split the aggregated data into three groups
data.w1 <- data[data$week==1,]
data.w2 <- data[data$week==2,]
data.w3 <- data[data$week==3,]

# calculate the means
mean.w1 <- mean(data.w1$score)
mean.w2 <- mean(data.w2$score)
mean.w3 <- mean(data.w3$score)

# construct individual CIs
ci.w1 <- t.test(data.w1$score)$conf.int
ci.w2 <- t.test(data.w2$score)$conf.int
ci.w3 <- t.test(data.w3$score)$conf.int

# construct the CI of all differences
ci.w21 <- t.test(data.w2$score - data.w1$score)$conf.int
ci.w32 <- t.test(data.w3$score - data.w2$score)$conf.int
ci.w31 <- t.test(data.w3$score - data.w1$score)$conf.int

# plot the CIs
par(mfrow=c(1,2), mar = c(4,4,1,1), pty='s', cex.main = 1.1)

plotCI(c(1, 2, 3), c(mean.w1, mean.w2, mean.w3),
    ui=c(ci.w1[2], ci.w2[2], ci.w3[2]),
    li=c(ci.w1[1], ci.w2[1], ci.w3[1]),
    pch=19, xlab=NA, xaxt='n', xlim=c(.5, 3.5), ylab="IQ Score")

axis(1, at = 1:3, labels = c("Week 1", "Week 2", "Week 3"))
segments(0, 100, 4, 100, lty=2)

plotCI(c(1, 2, 3), c(mean.w2 - mean.w1, mean.w3 - mean.w2, mean.w3 - mean.w1),
    ui=c(ci.w21[2], ci.w32[2], ci.w31[2]),
    li=c(ci.w21[1], ci.w32[1], ci.w31[1]),
    pch=19, xlab=NA, xaxt='n', xlim=c(.5, 3.5), ylab="Diff IQ Score")
axis(1, at = 1:3, labels = c("Weeks 2 - 1", "Weeks 3 - 2", "Weeks 3 - 1"))
segments(0, 0, 4, 0, lty=2)
