#Author: Theophanis Tsandilas
library(plotrix)

#read the data from a csv file
data <- read.csv(file="IQ-tests.csv", header=TRUE, sep=",")

# aggregate the scores by group and participant
data.aggr <- aggregate(score~group+participant+week, data, FUN = mean)

# split the aggregated data into two groups
data.control <- data.aggr[data.aggr$group=="control",]
data.geometry <- data.aggr[data.aggr$group=="geometry",]

# calculate the means
mean.control <- mean(data.control$score)
mean.geometry <- mean(data.geometry$score)

# construct individual CIs
ci.control <- t.test(data.control$score)$conf.int
ci.geometry <- t.test(data.geometry$score)$conf.int

# construct the CI of the difference
ci.diff <- t.test(data.geometry$score, data.control$score)$conf.int

# plot the CIs
par(mfrow=c(1,2), mar = c(4,4,1,1), pty='s', cex.main = 1.1)

plotCI(c(1,2), c(mean.control, mean.geometry), ui=c(ci.control[2],ci.geometry[2]), li=c(ci.control[1],ci.geometry[1]), pch=19, xlab=NA, xaxt='n', xlim=c(.5, 2.5), ylab="IQ Score")

axis(1, at = 1:2, labels = c("Control", "Geometry"))
segments(0, 100, 3, 100, lty=2)

plotCI(1, mean.geometry - mean.control, ui=ci.diff[2], li=ci.diff[1], pch=19, xlab=NA, xaxt='n', ylim=c(-2, 6), ylab="Diff IQ Score")
segments(0, 0, 2, 0, lty=2)
