# Author: Theophanis Tsandilas
# The script tests the coverage probabiity of CIs based on the t-distribution
# when estimating mean differences of samples drawn from skewed log-normal distributions

# Parameters of the log-normal distribution
m1 <- 4.5   # Mean of log-transformed values (normal distribution)
sd1 <- 0.5    # SD of log-transformed values (normal distribution)

m2 <- 4.8   # Mean of log-transformed values (normal distribution)
sd2 <- 0.4    # SD of log-transformed values (normal distribution)

# True population mean (mean of the original skewed distribution)
M1 <- exp(m1 + sd1^2/2)
M2 <- exp(m2 + sd2^2/2)

DM <- M1 - M2 # True difference between the two means

n <- 16 # Size of the samples

N <- 10000 # Number of sampling repetitions
count <- 0 # Counter of how many times the CI fails

for(i in 1:N){
    sample1 <- rlnorm(n, meanlog = m1, sdlog = sd1)
    sample2 <- rlnorm(n, meanlog = m2, sdlog = sd2)
    ci <- t.test(sample1, sample2, conf.level = .95)$conf.int
    
    if(ci[2] < DM || ci[1] > DM) count <- count + 1
}

cat("Average number of failures = ", count/N, "\n")
cat("Coverage probability = ", (1 - count/N)*100, "%\n")
