# Author: Theophanis Tsandilas
# Note: For a larger choice of graphing tools, you can use ggplot2: http://ggplot2.org/

library(plotrix)

# The data values are stored in two different vectors:
# We a assume a repeated measures design
ta <- c(530, 600, 556, 480, 578, 532, 740, 590, 612, 679)
tb <- c(511, 552, 430, 455, 610, 520, 731, 483, 610, 539)

# calculate the medians
ma <- median(ta)
mb <- median(tb)
mratio <- median(ta/tb)

#log-transform the data
logta <- log(ta)
logtb <- log(tb)

# Compute the CIs on a logartithmic scale
# Those are CIs of either the mean or the median of the log values
# However, we will treat them as medians
# in order to be able to apply the inverse transformation
lci.a <- t.test(logta)$conf.int
lci.b <- t.test(logtb)$conf.int

# Apply the t.test to find the 95%CI of their mean (and median) difference
lci.ab <- t.test(logta - logtb)$conf.int

# Transform the CIs back to their original scale
ci.a <- exp(lci.a) # 95% CIs of the median of population A
ci.b <- exp(lci.b) # 95% CIs of the median of population B
ci.ab <- exp(lci.ab) # 95% CIs of their median ratio (rather than difference)

# plot the bars and CIs
par(mfrow=c(1,2), mar = c(4,4,1,1), pty='s', cex.main = 1.1)

cbars <- barplot(height = c(ma, mb), ylab = "Median Selection Time (ms)",
      ylim = c(0,800), xlim = c(0,4), space=0.7, density = c(50,90), col = c("light gray", "dark gray"))
axis(1, at = cbars, labels=c("Technique A", "Technique B"))

# Creating the error bars (manually by drawing segments)
segments(x0 = cbars, x1 = cbars, y0 = c(ci.a[1], ci.b[1]), y1 = c(ci.a[2], ci.b[2]), lwd = 3)


# plot the CI of the ratio (by using the plotCI function of the plotrix package)
plotCI(1, mratio, ui=ci.ab[2], li=ci.ab[1], pch=19, xlab=NA, xaxt='n', ylim=c(.95, 1.2), ylab="Median Time Ratio (Techn.A / Techn.B)", lwd = 3, sfrac = 0)
segments(0, 1, 2, 1, lty=2)
